==> cms-db_v0.9.tar.gz: detect-browser.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	chdir('./admin');
	include('friendlyerror.firewall.inc.php');
	die();
}


$ua = strtolower($_SERVER['HTTP_USER_AGENT']);


$os = 'unknown';
if (strpos($ua, 'android') !== false) {
	$os = 'Android';
} elseif (strpos($ua, 'maemo') !== false) {
	$os = 'Maemo';
} elseif (strpos($ua, 'iphone') !== false or strpos($ua, 'ipod') !== false  or strpos($ua, 'ipad') !== false) {
	$os = 'iOS';
} elseif (strpos($ua, 'linux') !== false) {
	$os = 'Linux';
} elseif (strpos($ua, 'bsd') !== false) {
	$os = 'BSD';
} elseif (strpos($ua, 'windows') !== false) {
	$os = 'Windows';
	if (strpos($ua, 'windows nt') !== false) {
		if (strpos($ua, 'windows nt 6.1') !== false) {
			$os .= ' 7';
		} elseif (strpos($ua, 'windows nt 6.01') !== false) {
			$os .= ' Server 2008';
		} elseif (strpos($ua, 'windows nt 6.0') !== false) {
			$os .= ' Vista';
		} elseif (strpos($ua, 'windows nt 5.2') !== false) {
			$os .= ' XP 64 / Server 2003';
		} elseif (strpos($ua, 'windows nt 5.1') !== false) {
			$os .= ' XP';
		} elseif (strpos($ua, 'windows nt 5.0') !== false) {
			$os .= ' 2000';
		} else {
			$os .= ' NT';
		}
	} else {
		if (strpos($ua, 'windows 98') !== false) {
			$os .= ' 98';
		} elseif (strpos($ua, 'windows 95') !== false) {
			$os .= ' 95';
		} elseif (strpos($ua, 'windows 9x') !== false or strpos($ua, 'windows me') !== false) {
			$os .= ' ME';
		} elseif (strpos($ua, 'windows 3.1') !== false) {
			$os .= ' 3.1';
		} elseif (strpos($ua, 'windows ce') !== false) {
			$os .= ' CE';
		} elseif (strpos($ua, 'windows mobile') !== false) {
			$os .= ' Mobile';
		} elseif (strpos($ua, 'windows phone') !== false) {
			$os .= ' Mobile';
		}
	}
} elseif (strpos($ua, 'mac') !== false) {
	$os = 'Mac OS';
	if (strpos($ua, 'mac os x') !== false) {
		$os .= ' X';
	}
} elseif ( strpos($ua, 'google') !== false
		or strpos($ua, 'yahoo') !== false
		or strpos($ua, 'ask jeeves') !== false
		or strpos($ua, 'msnbot') !== false
		or strpos($ua, 'bot') !== false
		or strpos($ua, '+http') !== false) {
	$os = 'BOT';
} elseif ( strpos($ua, 'j2me') !== false
		or strpos($ua, 'midp') !== false
		or strpos($ua, 'cldc') !== false
		or strpos($ua, 'sonyericsson') !== false
		or strpos($ua, 'nokia') !== false
		or strpos($ua, 'fennec') !== false) {
	$os = 'Mobile';
}


$browsers = array();

#Format: $browsers[Suchmuster] = array(Anzeigename, Trennzeichen, array(Versionsnummern), Verwende Version/*?);
$browsers['maemo']          = array('Maemo Browser', false);
$browsers['firefox']        = array('Firefox', '/', array('4.0', '3.6', '3.5', '3.1', '3.0', '2.0', '1.5', '1.0'));
$browsers['opera/9.80']     = array('Opera', '/', array('11', '10'), true);
$browsers['opera']          = array('Opera', ' ', array('11', '10', '9', '8', '7', '6', '5'));
$browsers['opera']          = array('Opera', '/', array('11', '10', '9', '8', '7', '6', '5'));
$browsers['msie']           = array('MSIE', ' ', array('10', '9', '8', '7', '6', '5.5', '5', '4.5', '4', '3', '2'));
$browsers['konqueror']      = array('Konqueror', '/', array('4.7', '4.6', '4.5', '4.4', '4.3', '4.2', '4.1', '4', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0', '2.2', '2.1'));
$browsers['chrome']         = array('Chrome', '/', array('12.0', '11.0', '10.0', '9.0', '8.0', '7.0', '6.0', '5.0', '4.0', '3.0', '2.0', '1.0', '0.3', '0.2'));
$browsers['arora']          = array('Webkit based', false);
$browsers['midori']         = array('Webkit based', false);
$browsers['android']        = array('Android Browser', false);
$browsers['iphone']         = array('Mobile Safari', false);
$browsers['ipod']           = array('Mobile Safari', false);
$browsers['ipad']           = array('Mobile Safari', false);
$browsers['safari']         = array('Safari', '/', array('5.0', '4.0', '3.1', '3.0'), true);
$browsers['webkit']         = array('Webkit based', false);
$browsers['khtml']          = array('KHTML based', false);
$browsers['links']          = array('Text browser', false);
$browsers['lynx']           = array('Text browser', false);
$browsers['google']         = array('Bot', false);
$browsers['yahoo']          = array('Bot', false);
$browsers['ask jeeves']     = array('Bot', false);
$browsers['msnbot']         = array('Bot', false);
$browsers['bot']            = array('Bot', false);
$browsers['+http']          = array('Bot', false);
$browsers['j2me']           = array('Mobile', false);
$browsers['midp']           = array('Mobile', false);
$browsers['cldc']           = array('Mobile', false);
$browsers['sonyericsson']   = array('Mobile', false);
$browsers['nokia']          = array('Mobile', false);
$browsers['fennec']         = array('Mobile', false);
$browsers['windows mobile'] = array('Mobile', false);
$browsers['windows phone']  = array('Mobile', false);
$browsers['gecko']          = array('Gecko based', false);

$browser = 'unknown'."\n";
foreach ($browsers as $b => $data) {
	if (strpos($ua, $b) !== false) {
		$browser = $data[0]."\n";
		if ($data[1] != false) {
			if (!isset($data[3])) {
				$search = $b.$data[1];
			} else {
				$search = 'version'.$data[1];
			}
			foreach ($data[2] as $v) {
				if (strpos($ua, $search.$v) !== false) {
					$browser .= $v;
					break;
				}
			}
		}
		break;
	}
}


?>

==> cms-db_v0.9.3.tar.gz: detect-browser.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

if (!defined('cms-db')) {
	chdir('./admin');
	include('friendlyerror.firewall.inc.php');
	die();
}


$ua = strtolower($_SERVER['HTTP_USER_AGENT']);


$os = 'unknown';
if (strpos($ua, 'android') !== false) {
	$os = 'Android';
} elseif (strpos($ua, 'cros') !== false) {
	$os = 'Chrome OS';
} elseif (strpos($ua, 'maemo') !== false) {
	$os = 'Maemo';
} elseif (strpos($ua, 'iphone') !== false or strpos($ua, 'ipod') !== false) {
	$os = 'iOS';
} elseif (strpos($ua, 'ipad') !== false) {
	$os = 'iOS (Tablet)';
} elseif (strpos($ua, 'linux') !== false) {
	$os = 'Linux';
} elseif (strpos($ua, 'bsd') !== false) {
	$os = 'BSD';
} elseif (strpos($ua, 'windows') !== false) {
	$os = 'Windows';
	if (strpos($ua, 'windows nt') !== false) {
		if (strpos($ua, 'windows nt 6.1') !== false) {
			$os .= ' 7';
		} elseif (strpos($ua, 'windows nt 6.01') !== false) {
			$os .= ' Server 2008';
		} elseif (strpos($ua, 'windows nt 6.0') !== false) {
			$os .= ' Vista';
		} elseif (strpos($ua, 'windows nt 5.2') !== false) {
			$os .= ' XP 64 / Server 2003';
		} elseif (strpos($ua, 'windows nt 5.1') !== false) {
			$os .= ' XP';
		} elseif (strpos($ua, 'windows nt 5.0') !== false) {
			$os .= ' 2000';
		} else {
			$os .= ' NT';
		}
	} else {
		if (strpos($ua, 'windows 98') !== false) {
			$os .= ' 98';
		} elseif (strpos($ua, 'windows 95') !== false) {
			$os .= ' 95';
		} elseif (strpos($ua, 'windows 9x') !== false or strpos($ua, 'windows me') !== false) {
			$os .= ' ME';
		} elseif (strpos($ua, 'windows 3.1') !== false) {
			$os .= ' 3.1';
		} elseif (strpos($ua, 'windows ce') !== false) {
			$os .= ' CE';
		} elseif (strpos($ua, 'windows mobile') !== false) {
			$os .= ' Mobile';
		} elseif (strpos($ua, 'windows phone') !== false) {
			$os .= ' Mobile';
		}
	}
} elseif (strpos($ua, 'mac') !== false) {
	$os = 'Mac OS';
	if (strpos($ua, 'mac os x') !== false) {
		$os .= ' X';
	}
} elseif ( strpos($ua, 'google') !== false
		or strpos($ua, 'yahoo') !== false
		or strpos($ua, 'ask jeeves') !== false
		or strpos($ua, 'msnbot') !== false
		or strpos($ua, 'bot') !== false
		or strpos($ua, '+http') !== false) {
	$os = 'BOT';
} elseif ( strpos($ua, 'j2me') !== false
		or strpos($ua, 'midp') !== false
		or strpos($ua, 'cldc') !== false
		or strpos($ua, 'sonyericsson') !== false
		or strpos($ua, 'nokia') !== false
		or strpos($ua, 'fennec') !== false) {
	$os = 'Mobile';
}


$browsers = array();

#Format: $browsers[Suchmuster] = array(Anzeigename, Trennzeichen, array(Versionsnummern), Verwende Version/*?);
$browsers['maemo']          = array('Maemo Browser', false);
$browsers['firefox']        = array('Firefox', '/', array('6.0', '5.0', '4.0', '3.6', '3.5', '3.1', '3.0', '2.0', '1.5', '1.0'));
$browsers['opera/9.80']     = array('Opera', '/', array('13', '12', '11', '10'), true);
$browsers['opera']          = array('Opera', ' ', array('13', '12', '11', '10', '9', '8', '7', '6', '5'));
$browsers['opera']          = array('Opera', '/', array('13', '12', '11', '10', '9', '8', '7', '6', '5'));
$browsers['msie']           = array('MSIE', ' ', array('11', '10', '9', '8', '7', '6', '5.5', '5', '4.5', '4', '3', '2'));
$browsers['konqueror']      = array('Konqueror', '/', array('5.0', '4.7', '4.6', '4.5', '4.4', '4.3', '4.2', '4.1', '4', '3.5', '3.4', '3.3', '3.2', '3.1', '3.0', '2.2', '2.1'));
$browsers['chrome']         = array('Chrome', '/', array('16.0', '15.0', '14.0', '13.0', '12.0', '11.0', '10.0', '9.0', '8.0', '7.0', '6.0', '5.0', '4.0', '3.0', '2.0', '1.0', '0.3', '0.2'));
$browsers['arora']          = array('Webkit based', false);
$browsers['midori']         = array('Webkit based', false);
$browsers['android']        = array('Android Browser', false);
$browsers['android 3']      = array('Android Browser (Tablet)', false);
$browsers['iphone']         = array('Mobile Safari', false);
$browsers['ipod']           = array('Mobile Safari', false);
$browsers['ipad']           = array('Mobile Safari (Tablet)', false);
$browsers['safari']         = array('Safari', '/', array('6.0', '5.0', '4.0', '3.1', '3.0'), true);
$browsers['webkit']         = array('Webkit based', false);
$browsers['khtml']          = array('KHTML based', false);
$browsers['links']          = array('Text browser', false);
$browsers['lynx']           = array('Text browser', false);
$browsers['google']         = array('Bot', false);
$browsers['yahoo']          = array('Bot', false);
$browsers['ask jeeves']     = array('Bot', false);
$browsers['msnbot']         = array('Bot', false);
$browsers['bot']            = array('Bot', false);
$browsers['+http']          = array('Bot', false);
$browsers['j2me']           = array('Mobile', false);
$browsers['midp']           = array('Mobile', false);
$browsers['cldc']           = array('Mobile', false);
$browsers['sonyericsson']   = array('Mobile', false);
$browsers['nokia']          = array('Mobile', false);
$browsers['fennec']         = array('Mobile', false);
$browsers['windows mobile'] = array('Mobile', false);
$browsers['windows phone']  = array('Mobile', false);
$browsers['gecko']          = array('Gecko based', false);

$browser = 'unknown'."\n";
foreach ($browsers as $b => $data) {
	if (strpos($ua, $b) !== false) {
		$browser = $data[0]."\n";
		if ($data[1] != false) {
			if (!isset($data[3])) {
				$search = $b.$data[1];
			} else {
				$search = 'version'.$data[1];
			}
			foreach ($data[2] as $v) {
				if (strpos($ua, $search.$v) !== false) {
					$browser .= $v;
					break;
				}
			}
		}
		break;
	}
}


?>
